
From: Hugh Dickins <hugh@veritas.com>

ARM26 define FIRST_USER_ADDRESS as PAGE_SIZE (beyond the machine vectors when
they are mapped low), and use that definition in place of locally defined
MIN_MAP_ADDR.  Previously, ARM26 permitted user mappings at 0 if the machine
vectors were mapped high; but that's inconsistent with ARM, and
FIRST_USER_ADDRESS would then have to be determined at runtime.  Let's fix it
at PAGE_SIZE throughout the architecture.

Signed-off-by: Hugh Dickins <hugh@veritas.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/arm26/kernel/sys_arm.c |    9 ++++-----
 25-akpm/include/asm-arm26/pgtable.h |    7 +++++++
 2 files changed, 11 insertions(+), 5 deletions(-)

diff -puN arch/arm26/kernel/sys_arm.c~freepgt2-arm26-first_user_address-page_size arch/arm26/kernel/sys_arm.c
--- 25/arch/arm26/kernel/sys_arm.c~freepgt2-arm26-first_user_address-page_size	2005-04-06 18:22:08.000000000 -0700
+++ 25-akpm/arch/arm26/kernel/sys_arm.c	2005-04-06 18:22:08.000000000 -0700
@@ -64,10 +64,10 @@ inline long do_mmap2(
 	flags &= ~(MAP_EXECUTABLE | MAP_DENYWRITE);
 
 	/*
-	 * If we are doing a fixed mapping, and address < PAGE_SIZE,
+	 * If we are doing a fixed mapping, and address < FIRST_USER_ADDRESS,
 	 * then deny it.
 	 */
-	if (flags & MAP_FIXED && addr < PAGE_SIZE && vectors_base() == 0)
+	if (flags & MAP_FIXED && addr < FIRST_USER_ADDRESS)
 		goto out;
 
 	error = -EBADF;
@@ -121,11 +121,10 @@ sys_arm_mremap(unsigned long addr, unsig
 	unsigned long ret = -EINVAL;
 
 	/*
-	 * If we are doing a fixed mapping, and address < PAGE_SIZE,
+	 * If we are doing a fixed mapping, and address < FIRST_USER_ADDRESS,
 	 * then deny it.
 	 */
-	if (flags & MREMAP_FIXED && new_addr < PAGE_SIZE &&
-	    vectors_base() == 0)
+	if (flags & MREMAP_FIXED && new_addr < FIRST_USER_ADDRESS)
 		goto out;
 
 	down_write(&current->mm->mmap_sem);
diff -puN include/asm-arm26/pgtable.h~freepgt2-arm26-first_user_address-page_size include/asm-arm26/pgtable.h
--- 25/include/asm-arm26/pgtable.h~freepgt2-arm26-first_user_address-page_size	2005-04-06 18:22:08.000000000 -0700
+++ 25-akpm/include/asm-arm26/pgtable.h	2005-04-06 18:22:08.000000000 -0700
@@ -62,6 +62,13 @@
 #define PTRS_PER_PMD            1
 #define PTRS_PER_PTE            32
 
+/*
+ * This is the lowest virtual address we can permit any user space
+ * mapping to be mapped at.  This is particularly important for
+ * non-high vector CPUs.
+ */
+#define FIRST_USER_ADDRESS	PAGE_SIZE
+
 #define FIRST_USER_PGD_NR       1
 #define USER_PTRS_PER_PGD       ((TASK_SIZE/PGD_SIZE) - FIRST_USER_PGD_NR)
 
_
